%% Identification part:
% (The version from December 1996 (or newer) is needed because of
% the \ignorespacesafterend command.)

\NeedsTeXFormat{LaTeX2e}[1996/12/01]

\ProvidesClass{littprog}[2019/10/15 v1.6 A class for literate programs in Web0]

%% Initial code part:

%% Options declaration part:

\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}

%% Options execution part:

\ProcessOptions*

%% Package loading part:

\RequirePackage{alltt,mfirstuc,mflogo,rotating}
\RequirePackage[T1]{fontenc,url}   \urlstyle{sf}
\RequirePackage[UKenglish]{babel}
\RequirePackage[english]{varioref}
\RequirePackage{bera,arevmath,fakesc,relsize}
\RequirePackage[UKenglish]{ifikompendiumforside}
  \subtitle{Program source code and documentation}
\RequirePackage{lettrine}
  \renewcommand{\LettrineTextFont}{}

\LoadClass[11pt,twoside]{article}
\RequirePackage[a4paper,margin=2.5cm]{geometry}
 
\RequirePackage[english]{webzero}
\RequirePackage{fancyvrb,color,type1cm,type1ec}

%% Main code part:

\author{Dag Langmyhr (\url{dag@ifi.uio.no})}

% Layout parameters:

\pretolerance = 4000
\tolerance = 6000   \hbadness = \tolerance

\renewcommand{\floatpagefraction}{0.8}

% Various names and symbols:

\newcommand{\Asciienc}{\textsc{Ascii}}
\newcommand{\asciienc}{\textsc{{}ascii}}
\newcommand{\BibTeX}{\textsc{bib}\-\TeX}
\newcommand{\bnf}{\textsc{{}bnf}}
\newcommand{\Bnf}{\textsc{bnf}}
\newcommand{\bsl}{\textbackslash}
\newcommand{\CR}{\textsc{{}cr}}
\newcommand{\dash}{\textthreequartersemdash}
\newcommand{\dvi}{\textsc{{}dvi}}
\newcommand{\Dvi}{\textsc{dvi}}
\newcommand{\eps}{\textsc{{}eps}}
\newcommand{\Eps}{\textsc{eps}}
\newcommand{\html}{\textsc{{}html}}
\newcommand{\Html}{\textsc{html}}
\newcommand{\LF}{\textsc{{}lf}}
\newcommand{\pdf}{\textsc{{}pdf}}
\newcommand{\Pdf}{\textsc{pdf}}
\newcommand{\ps}{Post\-Script}
\newcommand{\Ps}{\ps}
\newcommand{\smiley}{\raisebox{-0.2ex}{\wasyb \symbol{"2C}}}
\newcommand{\TAB}{\textsc{tab}}
\newcommand{\utf}{\textsc{{}utf}-8}
\newcommand{\Utf}{\textsc{utf}-8}
\newcommand{\unix}{\textsc{{}unix}}
\newcommand{\Unix}{\textsc{unix}}

\newfont{\wasyb}{wasyb10 at 12pt}

% Specify the layout for various kinds of names:

\newcommand{\ascii}[1]{\textsc{{}#1}}
\newcommand{\Ascii}[1]{\textsc{#1}}  %% \textsc{\makefirstuc{\MakeLowercase{#1}}}}
\newcommand{\control}[1]{\textasciicircum #1}
\newcommand{\lacmd}[1]{\px{\textbackslash #1}}
\newcommand{\laenv}[2][]{\lacmd{begin}\lapar{#2}\px{#1}\dots
  \hspace{-2pt}\lacmd{end}\lapar{#2}}
\newcommand{\laopt}[1]{\px{[#1]}}
\newcommand{\lapackage}[1]{\px{#1}}
\newcommand{\lapar}[1]{\px{\textbraceleft #1\textbraceright}}
\newcommand{\macro}[1]{\ensuremath{\langle
    \mbox{\itshape #1\/}\rangle}}
\newcommand{\perlarray}[1]{\px{@#1}}
\newcommand{\perlfile}[1]{\px{#1}}
\newcommand{\perlfunc}[1]{\px{\&#1}}
\newcommand{\perlhash}[1]{\px{\%#1}}
\newcommand{\perltext}[1]{\px{"#1"}}
\newcommand{\perlvar}[1]{\px{\$#1}}
\newcommand{\prog}[1]{\px{#1}}
\newcommand{\progbf}[1]{\px{\bfseries #1}}
\newcommand{\psdir}[1]{\px{\%\%#1}}
\newcommand{\psenv}[1]{\psdir{Begin#1}\dots\hspace{-2pt}\psdir{End#1}}
\newcommand{\px}[1]{\texttt{#1}}
\newcommand{\pxbf}[1]{\texttt{\bfseries #1}}
\newcommand{\tighter}{\addtolength{\itemsep}{-1ex}}
\newcommand{\unixdir}[1]{\px{#1}}
\newcommand{\unixenvir}[1]{\px{\textsc{{}\uppercase{#1}}}}
\newcommand{\unixfile}[1]{\url{#1}}
\newcommand{\unixopt}[1]{\px{--#1}}
%% A special version of \unixopt that prevent line break after the
%% initial -. Only works when parameter is 2 or more characters.
\newcommand{\unixoptx}[1]{\px{{\mbox{--\Car#1}\Cdr#1}}}
\newcommand{\unixsignal}[1]{\px{\textsc{{}sig\lowercase{#1}}}}
\newcommand{\www}{\textsc{{}www}}
\newcommand{\Www}{\textsc{Www}}

\newcommand{\Car}[2]{#1}
\newcommand{\Cdr}[2]{#2}


% Modify the layout of the table of contents, allowing
% for a wider font (i.e., Bera):

\renewcommand{\l@subsection}{\@dottedtocline{2}{1.5em}{2.6em}}
\renewcommand{\l@subsubsection}{\@dottedtocline{3}{4.1em}{3.6em}}
\renewcommand{\l@paragraph}{\@dottedtocline{4}{7.7em}{4.6em}}
\renewcommand{\l@subparagraph}{\@dottedtocline{5}{12.3em}{5em}}


% Define an environment for the introduction (including the initial):

\renewcommand{\LettrineTextFont}{\upshape} %% as the text font may have no CSC variant
\newenvironment{introduction}[3][]%
  {\ififorside\relax
    \maketitle
    \lettrine[lines=3,lhang=0.32,#1]{\textbf{#2}}{\textsc{{}#3}}}%
  {\subsubsection*{Program documentation system}
    This program was documented using the \webzero{} package which
    is based on Donald Knuth's ideas of \emph{literate programming}.
    For more information on the \webzero{} implementation, see
    \url{http://dag.at.ifi.uio.no/public/doc/web0.pdf}.\par }


% Define an environment for command examples (including the local
% command \user):

\newenvironment{commex}%
  {\begin{quote}
    \def \user ##1{\% \textbf{##1}}
    \begin{alltt}}%
  {\end{alltt}\end{quote}\ignorespacesafterend }

% Define a version more like `verbose':

\newcommand{\exfile}[3][]{\begin{figure}
  \caption{#3}
  \VerbatimInput[fontsize=\footnotesize,fontfamily=\ttdefault,#1]{#2}
\end{figure}}

\newcommand{\bigexfile}[3][]{\begin{sidewaysfigure}
  \caption{#3}
  \VerbatimInput[fontsize=\footnotesize,fontfamily=\ttdefault,#1]{#2}
\end{sidewaysfigure}}

\DefineVerbatimEnvironment{ex}{Verbatim}{fontsize=\small,fontfamily=\ttdefault}
\newcommand{\prompt}[1]{\% \textbf{#1}}

% A command for frames containing additional information:

\newcommand{\infoframe}[2][]{\begin{figure}
    \def\title##1{\subsection*{##1}}
    \setlength{\fboxrule}{1.2pt}
    \setlength{\fboxsep}{1cm}
    \noindent\fbox{\begin{minipage}{\textwidth-2\fboxsep-2\fboxrule}
        \setlength{\parskip}{0.6\baselineskip}
        \small #1#2
      \end{minipage}}
    \end{figure}}
  
% An environment for notes that should catch the reader's attention:

\newenvironment{note}{\subparagraph*{Note!}}{\par}

% A list for parameter definitions:

\newenvironment{paramlist}
  {\begin{enumerate}\addtolength{\itemsep}{-1.5ex}}
  {\end{enumerate}}

% Corrections:

% Redefinition of standard \LaTeX command because font package
% 'bera' mangles it!
\DeclareRobustCommand{\ifik@LaTeX}{L\kern-.3em%
  {\sbox\z@ T%
    \vbox to\ht\z@{\hbox{\check@mathfonts
        \fontsize\sf@size\z@
        \math@fontsfalse\selectfont
        A}%
      \vss}%
  }%
  \kern-.05em%
  \TeX}%
\let \LaTeX = \ifik@LaTeX

% Other minor modifications:

\addtocounter{secnumdepth}{1}
\renewcommand{\@pnumwidth}{2em}

%% End:

\endinput
